==> mysql-8.0_8.0.36.orig.tar.gz: mysql-8.0.36/include/my_openssl_fips.h <==
/* Copyright (c) 2022, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   Without limiting anything contained in the foregoing, this file,
   which is part of C Driver for MySQL (Connector/C), is also subject to the
   Universal FOSS Exception, version 1.0, a copy of which can be found at
   http://oss.oracle.com/licenses/universal-foss-exception.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef my_openssl_fips_h_
#define my_openssl_fips_h_

constexpr int OPENSSL_ERROR_LENGTH{512}; /* Openssl error code max length */

bool set_fips_mode(const int fips_mode, char err_string[OPENSSL_ERROR_LENGTH]);
int get_fips_mode();

int test_ssl_fips_mode(char err_string[OPENSSL_ERROR_LENGTH]);

void fips_deinit();
void fips_init();

#endif /* ifndef my_openssl_fips_h_ */

==> mysql-8.4_8.4.6.orig.tar.gz: mysql-8.4.6/include/my_openssl_fips.h <==
/* Copyright (c) 2022, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   Without limiting anything contained in the foregoing, this file,
   which is part of C Driver for MySQL (Connector/C), is also subject to the
   Universal FOSS Exception, version 1.0, a copy of which can be found at
   http://oss.oracle.com/licenses/universal-foss-exception.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef my_openssl_fips_h_
#define my_openssl_fips_h_

constexpr int OPENSSL_ERROR_LENGTH{512}; /* Openssl error code max length */

bool set_fips_mode(const int fips_mode, char err_string[OPENSSL_ERROR_LENGTH]);
int get_fips_mode();

int test_ssl_fips_mode(char err_string[OPENSSL_ERROR_LENGTH]);

void fips_deinit();
void fips_init();

#endif /* ifndef my_openssl_fips_h_ */
